@@ -1,4 +1,5 @@
-from .init import init_jl, load_project, init_project, include_src, exec_julia
+from .init import init_jl
+from .apis import load_project, init_project, include_src, exec_julia
 from .defaults import setup_julia, install_julia
 from .utils import set_julia_mirror, set_julia_path
-from numpy import *
\ No newline at end of file
+from numpy import *
